@@ -3,7 +3,6 @@ import time
 from collections import namedtuple
 import weakref
 
-import traceback
 from pprint import pformat
 from typing import Union, Iterator
 
@@ -419,8 +418,10 @@ def wait_on_async_results(results,
 
             result_state = handle_broker_timeout(getattr, args=(result, 'state'))
             if result_state == REVOKED:
-                #  wait for revoked tasks to actually finish running
-                wait_for_running_tasks_from_results([result])
+                # Wait for revoked tasks to actually finish running
+                # Somewhat long max_wait in case a task does work when revoked, like
+                # killing a child run launched by the task.
+                wait_for_running_tasks_from_results([result], max_wait=5*60)
                 raise ChainRevokedException(task_id=str(result),
                                             task_name=get_task_name_from_result(result))
             if result_state == PENDING:
@@ -683,6 +684,22 @@ def get_results(result: AsyncResult,
         return results2tuple(extracted_dict, return_keys)
 
 
+def get_results_with_default(result: AsyncResult,
+                             default=None,
+                             error_msg: str = None,
+                             **kwargs):
+    if result.successful():
+        return get_results(result, **kwargs)
+    else:
+        if isinstance(getattr(result, 'result'), Exception):
+            exc_info = result.result
+        else:
+            exc_info = None
+        error_msg = error_msg or f'Unable to get result from {result}'
+        logger.error(error_msg, exc_info=exc_info)
+        return default
+
+
 FIREX_AR_REFS_ATTR = '__firex_ar_refs__'
 
 
